# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AssetArgs', 'Asset']

@pulumi.input_type
class AssetArgs:
    def __init__(__self__, *,
                 asset_type: pulumi.Input[str],
                 compartment_id: pulumi.Input[str],
                 external_asset_key: pulumi.Input[str],
                 inventory_id: pulumi.Input[str],
                 source_key: pulumi.Input[str],
                 asset_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 compute: Optional[pulumi.Input['AssetComputeArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 vm: Optional[pulumi.Input['AssetVmArgs']] = None,
                 vmware_vcenter: Optional[pulumi.Input['AssetVmwareVcenterArgs']] = None,
                 vmware_vm: Optional[pulumi.Input['AssetVmwareVmArgs']] = None):
        """
        The set of arguments for constructing a Asset resource.
        :param pulumi.Input[str] asset_type: (Updatable) The type of asset.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the asset belongs to.
        :param pulumi.Input[str] external_asset_key: The key of the asset from the external environment.
        :param pulumi.Input[str] inventory_id: Inventory ID to which an asset belongs.
        :param pulumi.Input[str] source_key: The source key to which the asset belongs.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] asset_source_ids: (Updatable) List of asset source OCID.
        :param pulumi.Input['AssetComputeArgs'] compute: (Updatable) Compute related properties.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Asset display name.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input['AssetVmArgs'] vm: (Updatable) Virtual machine related properties.
        :param pulumi.Input['AssetVmwareVcenterArgs'] vmware_vcenter: (Updatable) VMware vCenter related properties.
        :param pulumi.Input['AssetVmwareVmArgs'] vmware_vm: (Updatable) VMware virtual machine related properties.
        """
        pulumi.set(__self__, "asset_type", asset_type)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "external_asset_key", external_asset_key)
        pulumi.set(__self__, "inventory_id", inventory_id)
        pulumi.set(__self__, "source_key", source_key)
        if asset_source_ids is not None:
            pulumi.set(__self__, "asset_source_ids", asset_source_ids)
        if compute is not None:
            pulumi.set(__self__, "compute", compute)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if vm is not None:
            pulumi.set(__self__, "vm", vm)
        if vmware_vcenter is not None:
            pulumi.set(__self__, "vmware_vcenter", vmware_vcenter)
        if vmware_vm is not None:
            pulumi.set(__self__, "vmware_vm", vmware_vm)

    @property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> pulumi.Input[str]:
        """
        (Updatable) The type of asset.
        """
        return pulumi.get(self, "asset_type")

    @asset_type.setter
    def asset_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "asset_type", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The OCID of the compartment that the asset belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="externalAssetKey")
    def external_asset_key(self) -> pulumi.Input[str]:
        """
        The key of the asset from the external environment.
        """
        return pulumi.get(self, "external_asset_key")

    @external_asset_key.setter
    def external_asset_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "external_asset_key", value)

    @property
    @pulumi.getter(name="inventoryId")
    def inventory_id(self) -> pulumi.Input[str]:
        """
        Inventory ID to which an asset belongs.
        """
        return pulumi.get(self, "inventory_id")

    @inventory_id.setter
    def inventory_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "inventory_id", value)

    @property
    @pulumi.getter(name="sourceKey")
    def source_key(self) -> pulumi.Input[str]:
        """
        The source key to which the asset belongs.
        """
        return pulumi.get(self, "source_key")

    @source_key.setter
    def source_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "source_key", value)

    @property
    @pulumi.getter(name="assetSourceIds")
    def asset_source_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) List of asset source OCID.
        """
        return pulumi.get(self, "asset_source_ids")

    @asset_source_ids.setter
    def asset_source_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "asset_source_ids", value)

    @property
    @pulumi.getter
    def compute(self) -> Optional[pulumi.Input['AssetComputeArgs']]:
        """
        (Updatable) Compute related properties.
        """
        return pulumi.get(self, "compute")

    @compute.setter
    def compute(self, value: Optional[pulumi.Input['AssetComputeArgs']]):
        pulumi.set(self, "compute", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Asset display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def vm(self) -> Optional[pulumi.Input['AssetVmArgs']]:
        """
        (Updatable) Virtual machine related properties.
        """
        return pulumi.get(self, "vm")

    @vm.setter
    def vm(self, value: Optional[pulumi.Input['AssetVmArgs']]):
        pulumi.set(self, "vm", value)

    @property
    @pulumi.getter(name="vmwareVcenter")
    def vmware_vcenter(self) -> Optional[pulumi.Input['AssetVmwareVcenterArgs']]:
        """
        (Updatable) VMware vCenter related properties.
        """
        return pulumi.get(self, "vmware_vcenter")

    @vmware_vcenter.setter
    def vmware_vcenter(self, value: Optional[pulumi.Input['AssetVmwareVcenterArgs']]):
        pulumi.set(self, "vmware_vcenter", value)

    @property
    @pulumi.getter(name="vmwareVm")
    def vmware_vm(self) -> Optional[pulumi.Input['AssetVmwareVmArgs']]:
        """
        (Updatable) VMware virtual machine related properties.
        """
        return pulumi.get(self, "vmware_vm")

    @vmware_vm.setter
    def vmware_vm(self, value: Optional[pulumi.Input['AssetVmwareVmArgs']]):
        pulumi.set(self, "vmware_vm", value)


@pulumi.input_type
class _AssetState:
    def __init__(__self__, *,
                 asset_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 asset_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 compute: Optional[pulumi.Input['AssetComputeArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 external_asset_key: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 inventory_id: Optional[pulumi.Input[str]] = None,
                 source_key: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None,
                 vm: Optional[pulumi.Input['AssetVmArgs']] = None,
                 vmware_vcenter: Optional[pulumi.Input['AssetVmwareVcenterArgs']] = None,
                 vmware_vm: Optional[pulumi.Input['AssetVmwareVmArgs']] = None):
        """
        Input properties used for looking up and filtering Asset resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] asset_source_ids: (Updatable) List of asset source OCID.
        :param pulumi.Input[str] asset_type: (Updatable) The type of asset.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the asset belongs to.
        :param pulumi.Input['AssetComputeArgs'] compute: (Updatable) Compute related properties.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Asset display name.
        :param pulumi.Input[str] external_asset_key: The key of the asset from the external environment.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] inventory_id: Inventory ID to which an asset belongs.
        :param pulumi.Input[str] source_key: The source key to which the asset belongs.
        :param pulumi.Input[str] state: The current state of the asset.
        :param pulumi.Input[Mapping[str, Any]] system_tags: The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        :param pulumi.Input[str] time_created: The time when the asset was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time when the asset was updated. An RFC3339 formatted datetime string.
        :param pulumi.Input['AssetVmArgs'] vm: (Updatable) Virtual machine related properties.
        :param pulumi.Input['AssetVmwareVcenterArgs'] vmware_vcenter: (Updatable) VMware vCenter related properties.
        :param pulumi.Input['AssetVmwareVmArgs'] vmware_vm: (Updatable) VMware virtual machine related properties.
        """
        if asset_source_ids is not None:
            pulumi.set(__self__, "asset_source_ids", asset_source_ids)
        if asset_type is not None:
            pulumi.set(__self__, "asset_type", asset_type)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if compute is not None:
            pulumi.set(__self__, "compute", compute)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if external_asset_key is not None:
            pulumi.set(__self__, "external_asset_key", external_asset_key)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if inventory_id is not None:
            pulumi.set(__self__, "inventory_id", inventory_id)
        if source_key is not None:
            pulumi.set(__self__, "source_key", source_key)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)
        if vm is not None:
            pulumi.set(__self__, "vm", vm)
        if vmware_vcenter is not None:
            pulumi.set(__self__, "vmware_vcenter", vmware_vcenter)
        if vmware_vm is not None:
            pulumi.set(__self__, "vmware_vm", vmware_vm)

    @property
    @pulumi.getter(name="assetSourceIds")
    def asset_source_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) List of asset source OCID.
        """
        return pulumi.get(self, "asset_source_ids")

    @asset_source_ids.setter
    def asset_source_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "asset_source_ids", value)

    @property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The type of asset.
        """
        return pulumi.get(self, "asset_type")

    @asset_type.setter
    def asset_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "asset_type", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The OCID of the compartment that the asset belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def compute(self) -> Optional[pulumi.Input['AssetComputeArgs']]:
        """
        (Updatable) Compute related properties.
        """
        return pulumi.get(self, "compute")

    @compute.setter
    def compute(self, value: Optional[pulumi.Input['AssetComputeArgs']]):
        pulumi.set(self, "compute", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Asset display name.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="externalAssetKey")
    def external_asset_key(self) -> Optional[pulumi.Input[str]]:
        """
        The key of the asset from the external environment.
        """
        return pulumi.get(self, "external_asset_key")

    @external_asset_key.setter
    def external_asset_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_asset_key", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="inventoryId")
    def inventory_id(self) -> Optional[pulumi.Input[str]]:
        """
        Inventory ID to which an asset belongs.
        """
        return pulumi.get(self, "inventory_id")

    @inventory_id.setter
    def inventory_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "inventory_id", value)

    @property
    @pulumi.getter(name="sourceKey")
    def source_key(self) -> Optional[pulumi.Input[str]]:
        """
        The source key to which the asset belongs.
        """
        return pulumi.get(self, "source_key")

    @source_key.setter
    def source_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "source_key", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the asset.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the asset was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The time when the asset was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)

    @property
    @pulumi.getter
    def vm(self) -> Optional[pulumi.Input['AssetVmArgs']]:
        """
        (Updatable) Virtual machine related properties.
        """
        return pulumi.get(self, "vm")

    @vm.setter
    def vm(self, value: Optional[pulumi.Input['AssetVmArgs']]):
        pulumi.set(self, "vm", value)

    @property
    @pulumi.getter(name="vmwareVcenter")
    def vmware_vcenter(self) -> Optional[pulumi.Input['AssetVmwareVcenterArgs']]:
        """
        (Updatable) VMware vCenter related properties.
        """
        return pulumi.get(self, "vmware_vcenter")

    @vmware_vcenter.setter
    def vmware_vcenter(self, value: Optional[pulumi.Input['AssetVmwareVcenterArgs']]):
        pulumi.set(self, "vmware_vcenter", value)

    @property
    @pulumi.getter(name="vmwareVm")
    def vmware_vm(self) -> Optional[pulumi.Input['AssetVmwareVmArgs']]:
        """
        (Updatable) VMware virtual machine related properties.
        """
        return pulumi.get(self, "vmware_vm")

    @vmware_vm.setter
    def vmware_vm(self, value: Optional[pulumi.Input['AssetVmwareVmArgs']]):
        pulumi.set(self, "vmware_vm", value)


class Asset(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asset_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 asset_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 compute: Optional[pulumi.Input[pulumi.InputType['AssetComputeArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 external_asset_key: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 inventory_id: Optional[pulumi.Input[str]] = None,
                 source_key: Optional[pulumi.Input[str]] = None,
                 vm: Optional[pulumi.Input[pulumi.InputType['AssetVmArgs']]] = None,
                 vmware_vcenter: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVcenterArgs']]] = None,
                 vmware_vm: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVmArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Asset resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an asset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_asset = oci.cloud_bridge.Asset("testAsset",
            asset_type=var["asset_asset_type"],
            compartment_id=var["compartment_id"],
            external_asset_key=var["asset_external_asset_key"],
            inventory_id=oci_cloud_bridge_inventory["test_inventory"]["id"],
            source_key=var["asset_source_key"],
            asset_source_ids=var["asset_asset_source_ids"],
            compute=oci.cloud_bridge.AssetComputeArgs(
                connected_networks=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cores_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cpu_model=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                disks=[oci.cloud_bridge.AssetComputeDiskArgs(
                    boot_order=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    location=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    persistent_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    size_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    uuid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    uuid_lun=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                disks_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                dns_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                firmware=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                gpu_devices=[oci.cloud_bridge.AssetComputeGpuDeviceArgs(
                    cores_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    manufacturer=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    memory_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                gpu_devices_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                guest_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hardware_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                host_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_pmem_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_tpm_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                latency_sensitivity=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                memory_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                nics=[oci.cloud_bridge.AssetComputeNicArgs(
                    ip_addresses=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    mac_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    mac_address_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    network_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    switch_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                nics_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                nvdimm_controller=oci.cloud_bridge.AssetComputeNvdimmControllerArgs(
                    bus_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                nvdimms=[oci.cloud_bridge.AssetComputeNvdimmArgs(
                    controller_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    unit_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                operating_system=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                operating_system_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                pmem_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                power_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                primary_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                scsi_controller=oci.cloud_bridge.AssetComputeScsiControllerArgs(
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shared_bus=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    unit_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                storage_provisioned_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                threads_per_core_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["asset_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            vm=oci.cloud_bridge.AssetVmArgs(
                hypervisor_host=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hypervisor_vendor=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hypervisor_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            vmware_vcenter=oci.cloud_bridge.AssetVmwareVcenterArgs(
                data_center=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vcenter_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vcenter_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            vmware_vm=oci.cloud_bridge.AssetVmwareVmArgs(
                cluster=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                customer_fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                customer_tags=[oci.cloud_bridge.AssetVmwareVmCustomerTagArgs(
                    description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                fault_tolerance_bandwidth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                fault_tolerance_secondary_latency=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                fault_tolerance_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                instance_uuid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_disks_cbt_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_disks_uuid_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vmware_tools_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        Assets can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/asset:Asset test_asset "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] asset_source_ids: (Updatable) List of asset source OCID.
        :param pulumi.Input[str] asset_type: (Updatable) The type of asset.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the asset belongs to.
        :param pulumi.Input[pulumi.InputType['AssetComputeArgs']] compute: (Updatable) Compute related properties.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Asset display name.
        :param pulumi.Input[str] external_asset_key: The key of the asset from the external environment.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] inventory_id: Inventory ID to which an asset belongs.
        :param pulumi.Input[str] source_key: The source key to which the asset belongs.
        :param pulumi.Input[pulumi.InputType['AssetVmArgs']] vm: (Updatable) Virtual machine related properties.
        :param pulumi.Input[pulumi.InputType['AssetVmwareVcenterArgs']] vmware_vcenter: (Updatable) VMware vCenter related properties.
        :param pulumi.Input[pulumi.InputType['AssetVmwareVmArgs']] vmware_vm: (Updatable) VMware virtual machine related properties.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AssetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Asset resource in Oracle Cloud Infrastructure Cloud Bridge service.

        Creates an asset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_asset = oci.cloud_bridge.Asset("testAsset",
            asset_type=var["asset_asset_type"],
            compartment_id=var["compartment_id"],
            external_asset_key=var["asset_external_asset_key"],
            inventory_id=oci_cloud_bridge_inventory["test_inventory"]["id"],
            source_key=var["asset_source_key"],
            asset_source_ids=var["asset_asset_source_ids"],
            compute=oci.cloud_bridge.AssetComputeArgs(
                connected_networks=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cores_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                cpu_model=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                disks=[oci.cloud_bridge.AssetComputeDiskArgs(
                    boot_order=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    location=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    persistent_mode=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    size_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    uuid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    uuid_lun=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                disks_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                dns_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                firmware=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                gpu_devices=[oci.cloud_bridge.AssetComputeGpuDeviceArgs(
                    cores_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    manufacturer=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    memory_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                gpu_devices_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                guest_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hardware_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                host_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_pmem_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_tpm_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                latency_sensitivity=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                memory_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                nics=[oci.cloud_bridge.AssetComputeNicArgs(
                    ip_addresses=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    mac_address=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    mac_address_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    network_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    switch_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                nics_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                nvdimm_controller=oci.cloud_bridge.AssetComputeNvdimmControllerArgs(
                    bus_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                nvdimms=[oci.cloud_bridge.AssetComputeNvdimmArgs(
                    controller_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    unit_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                operating_system=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                operating_system_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                pmem_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                power_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                primary_ip=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                scsi_controller=oci.cloud_bridge.AssetComputeScsiControllerArgs(
                    label=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    shared_bus=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    unit_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                ),
                storage_provisioned_in_mbs=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                threads_per_core_count=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["asset_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            vm=oci.cloud_bridge.AssetVmArgs(
                hypervisor_host=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hypervisor_vendor=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                hypervisor_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            vmware_vcenter=oci.cloud_bridge.AssetVmwareVcenterArgs(
                data_center=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vcenter_key=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vcenter_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            vmware_vm=oci.cloud_bridge.AssetVmwareVmArgs(
                cluster=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                customer_fields=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                customer_tags=[oci.cloud_bridge.AssetVmwareVmCustomerTagArgs(
                    description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
                fault_tolerance_bandwidth=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                fault_tolerance_secondary_latency=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                fault_tolerance_state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                instance_uuid=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_disks_cbt_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_disks_uuid_enabled=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vmware_tools_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        Assets can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:CloudBridge/asset:Asset test_asset "id"
        ```

        :param str resource_name: The name of the resource.
        :param AssetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AssetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asset_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 asset_type: Optional[pulumi.Input[str]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 compute: Optional[pulumi.Input[pulumi.InputType['AssetComputeArgs']]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 external_asset_key: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 inventory_id: Optional[pulumi.Input[str]] = None,
                 source_key: Optional[pulumi.Input[str]] = None,
                 vm: Optional[pulumi.Input[pulumi.InputType['AssetVmArgs']]] = None,
                 vmware_vcenter: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVcenterArgs']]] = None,
                 vmware_vm: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVmArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AssetArgs.__new__(AssetArgs)

            __props__.__dict__["asset_source_ids"] = asset_source_ids
            if asset_type is None and not opts.urn:
                raise TypeError("Missing required property 'asset_type'")
            __props__.__dict__["asset_type"] = asset_type
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["compute"] = compute
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            if external_asset_key is None and not opts.urn:
                raise TypeError("Missing required property 'external_asset_key'")
            __props__.__dict__["external_asset_key"] = external_asset_key
            __props__.__dict__["freeform_tags"] = freeform_tags
            if inventory_id is None and not opts.urn:
                raise TypeError("Missing required property 'inventory_id'")
            __props__.__dict__["inventory_id"] = inventory_id
            if source_key is None and not opts.urn:
                raise TypeError("Missing required property 'source_key'")
            __props__.__dict__["source_key"] = source_key
            __props__.__dict__["vm"] = vm
            __props__.__dict__["vmware_vcenter"] = vmware_vcenter
            __props__.__dict__["vmware_vm"] = vmware_vm
            __props__.__dict__["state"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(Asset, __self__).__init__(
            'oci:CloudBridge/asset:Asset',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asset_source_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            asset_type: Optional[pulumi.Input[str]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            compute: Optional[pulumi.Input[pulumi.InputType['AssetComputeArgs']]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            external_asset_key: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            inventory_id: Optional[pulumi.Input[str]] = None,
            source_key: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None,
            vm: Optional[pulumi.Input[pulumi.InputType['AssetVmArgs']]] = None,
            vmware_vcenter: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVcenterArgs']]] = None,
            vmware_vm: Optional[pulumi.Input[pulumi.InputType['AssetVmwareVmArgs']]] = None) -> 'Asset':
        """
        Get an existing Asset resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] asset_source_ids: (Updatable) List of asset source OCID.
        :param pulumi.Input[str] asset_type: (Updatable) The type of asset.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment that the asset belongs to.
        :param pulumi.Input[pulumi.InputType['AssetComputeArgs']] compute: (Updatable) Compute related properties.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) Asset display name.
        :param pulumi.Input[str] external_asset_key: The key of the asset from the external environment.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] inventory_id: Inventory ID to which an asset belongs.
        :param pulumi.Input[str] source_key: The source key to which the asset belongs.
        :param pulumi.Input[str] state: The current state of the asset.
        :param pulumi.Input[Mapping[str, Any]] system_tags: The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        :param pulumi.Input[str] time_created: The time when the asset was created. An RFC3339 formatted datetime string.
        :param pulumi.Input[str] time_updated: The time when the asset was updated. An RFC3339 formatted datetime string.
        :param pulumi.Input[pulumi.InputType['AssetVmArgs']] vm: (Updatable) Virtual machine related properties.
        :param pulumi.Input[pulumi.InputType['AssetVmwareVcenterArgs']] vmware_vcenter: (Updatable) VMware vCenter related properties.
        :param pulumi.Input[pulumi.InputType['AssetVmwareVmArgs']] vmware_vm: (Updatable) VMware virtual machine related properties.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AssetState.__new__(_AssetState)

        __props__.__dict__["asset_source_ids"] = asset_source_ids
        __props__.__dict__["asset_type"] = asset_type
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["compute"] = compute
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["external_asset_key"] = external_asset_key
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["inventory_id"] = inventory_id
        __props__.__dict__["source_key"] = source_key
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        __props__.__dict__["vm"] = vm
        __props__.__dict__["vmware_vcenter"] = vmware_vcenter
        __props__.__dict__["vmware_vm"] = vmware_vm
        return Asset(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="assetSourceIds")
    def asset_source_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        (Updatable) List of asset source OCID.
        """
        return pulumi.get(self, "asset_source_ids")

    @property
    @pulumi.getter(name="assetType")
    def asset_type(self) -> pulumi.Output[str]:
        """
        (Updatable) The type of asset.
        """
        return pulumi.get(self, "asset_type")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The OCID of the compartment that the asset belongs to.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def compute(self) -> pulumi.Output['outputs.AssetCompute']:
        """
        (Updatable) Compute related properties.
        """
        return pulumi.get(self, "compute")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Asset display name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="externalAssetKey")
    def external_asset_key(self) -> pulumi.Output[str]:
        """
        The key of the asset from the external environment.
        """
        return pulumi.get(self, "external_asset_key")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no predefined name, type, or namespace/scope. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="inventoryId")
    def inventory_id(self) -> pulumi.Output[str]:
        """
        Inventory ID to which an asset belongs.
        """
        return pulumi.get(self, "inventory_id")

    @property
    @pulumi.getter(name="sourceKey")
    def source_key(self) -> pulumi.Output[str]:
        """
        The source key to which the asset belongs.
        """
        return pulumi.get(self, "source_key")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the asset.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm). Example: `{orcl-cloud: {free-tier-retain: true}}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The time when the asset was created. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The time when the asset was updated. An RFC3339 formatted datetime string.
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def vm(self) -> pulumi.Output['outputs.AssetVm']:
        """
        (Updatable) Virtual machine related properties.
        """
        return pulumi.get(self, "vm")

    @property
    @pulumi.getter(name="vmwareVcenter")
    def vmware_vcenter(self) -> pulumi.Output['outputs.AssetVmwareVcenter']:
        """
        (Updatable) VMware vCenter related properties.
        """
        return pulumi.get(self, "vmware_vcenter")

    @property
    @pulumi.getter(name="vmwareVm")
    def vmware_vm(self) -> pulumi.Output['outputs.AssetVmwareVm']:
        """
        (Updatable) VMware virtual machine related properties.
        """
        return pulumi.get(self, "vmware_vm")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetExternalAsmDiskGroupsResult',
    'AwaitableGetExternalAsmDiskGroupsResult',
    'get_external_asm_disk_groups',
    'get_external_asm_disk_groups_output',
]

@pulumi.output_type
class GetExternalAsmDiskGroupsResult:
    """
    A collection of values returned by getExternalAsmDiskGroups.
    """
    def __init__(__self__, external_asm_disk_group_collections=None, external_asm_id=None, filters=None, id=None):
        if external_asm_disk_group_collections and not isinstance(external_asm_disk_group_collections, list):
            raise TypeError("Expected argument 'external_asm_disk_group_collections' to be a list")
        pulumi.set(__self__, "external_asm_disk_group_collections", external_asm_disk_group_collections)
        if external_asm_id and not isinstance(external_asm_id, str):
            raise TypeError("Expected argument 'external_asm_id' to be a str")
        pulumi.set(__self__, "external_asm_id", external_asm_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="externalAsmDiskGroupCollections")
    def external_asm_disk_group_collections(self) -> Sequence['outputs.GetExternalAsmDiskGroupsExternalAsmDiskGroupCollectionResult']:
        """
        The list of external_asm_disk_group_collection.
        """
        return pulumi.get(self, "external_asm_disk_group_collections")

    @property
    @pulumi.getter(name="externalAsmId")
    def external_asm_id(self) -> str:
        return pulumi.get(self, "external_asm_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetExternalAsmDiskGroupsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetExternalAsmDiskGroupsResult(GetExternalAsmDiskGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExternalAsmDiskGroupsResult(
            external_asm_disk_group_collections=self.external_asm_disk_group_collections,
            external_asm_id=self.external_asm_id,
            filters=self.filters,
            id=self.id)


def get_external_asm_disk_groups(external_asm_id: Optional[str] = None,
                                 filters: Optional[Sequence[pulumi.InputType['GetExternalAsmDiskGroupsFilterArgs']]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExternalAsmDiskGroupsResult:
    """
    This data source provides the list of External Asm Disk Groups in Oracle Cloud Infrastructure Database Management service.

    Lists ASM disk groups for the external ASM specified by `externalAsmId`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_asm_disk_groups = oci.DatabaseManagement.get_external_asm_disk_groups(external_asm_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_asm_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external ASM.
    """
    __args__ = dict()
    __args__['externalAsmId'] = external_asm_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getExternalAsmDiskGroups:getExternalAsmDiskGroups', __args__, opts=opts, typ=GetExternalAsmDiskGroupsResult).value

    return AwaitableGetExternalAsmDiskGroupsResult(
        external_asm_disk_group_collections=__ret__.external_asm_disk_group_collections,
        external_asm_id=__ret__.external_asm_id,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_external_asm_disk_groups)
def get_external_asm_disk_groups_output(external_asm_id: Optional[pulumi.Input[str]] = None,
                                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetExternalAsmDiskGroupsFilterArgs']]]]] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetExternalAsmDiskGroupsResult]:
    """
    This data source provides the list of External Asm Disk Groups in Oracle Cloud Infrastructure Database Management service.

    Lists ASM disk groups for the external ASM specified by `externalAsmId`.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_asm_disk_groups = oci.DatabaseManagement.get_external_asm_disk_groups(external_asm_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_asm_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external ASM.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetInfrastructureTargetVersionResult',
    'AwaitableGetInfrastructureTargetVersionResult',
    'get_infrastructure_target_version',
    'get_infrastructure_target_version_output',
]

@pulumi.output_type
class GetInfrastructureTargetVersionResult:
    """
    A collection of values returned by getInfrastructureTargetVersion.
    """
    def __init__(__self__, compartment_id=None, id=None, target_db_version_history_entries=None, target_resource_id=None, target_resource_type=None, target_storage_version_history_entries=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if target_db_version_history_entries and not isinstance(target_db_version_history_entries, list):
            raise TypeError("Expected argument 'target_db_version_history_entries' to be a list")
        pulumi.set(__self__, "target_db_version_history_entries", target_db_version_history_entries)
        if target_resource_id and not isinstance(target_resource_id, str):
            raise TypeError("Expected argument 'target_resource_id' to be a str")
        pulumi.set(__self__, "target_resource_id", target_resource_id)
        if target_resource_type and not isinstance(target_resource_type, str):
            raise TypeError("Expected argument 'target_resource_type' to be a str")
        pulumi.set(__self__, "target_resource_type", target_resource_type)
        if target_storage_version_history_entries and not isinstance(target_storage_version_history_entries, list):
            raise TypeError("Expected argument 'target_storage_version_history_entries' to be a list")
        pulumi.set(__self__, "target_storage_version_history_entries", target_storage_version_history_entries)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="targetDbVersionHistoryEntries")
    def target_db_version_history_entries(self) -> Sequence[str]:
        """
        The history entry of the target system software version for the database server patching operation.
        """
        return pulumi.get(self, "target_db_version_history_entries")

    @property
    @pulumi.getter(name="targetResourceId")
    def target_resource_id(self) -> Optional[str]:
        """
        The OCID of the target Exadata Infrastructure resource that will receive the maintenance update.
        """
        return pulumi.get(self, "target_resource_id")

    @property
    @pulumi.getter(name="targetResourceType")
    def target_resource_type(self) -> Optional[str]:
        """
        The resource type of the target Exadata infrastructure resource that will receive the system software update.
        """
        return pulumi.get(self, "target_resource_type")

    @property
    @pulumi.getter(name="targetStorageVersionHistoryEntries")
    def target_storage_version_history_entries(self) -> Sequence[str]:
        """
        The history entry of the target storage cell system software version for the storage cell patching operation.
        """
        return pulumi.get(self, "target_storage_version_history_entries")


class AwaitableGetInfrastructureTargetVersionResult(GetInfrastructureTargetVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInfrastructureTargetVersionResult(
            compartment_id=self.compartment_id,
            id=self.id,
            target_db_version_history_entries=self.target_db_version_history_entries,
            target_resource_id=self.target_resource_id,
            target_resource_type=self.target_resource_type,
            target_storage_version_history_entries=self.target_storage_version_history_entries)


def get_infrastructure_target_version(compartment_id: Optional[str] = None,
                                      target_resource_id: Optional[str] = None,
                                      target_resource_type: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInfrastructureTargetVersionResult:
    """
    This data source provides details about a specific Infrastructure Target Version resource in Oracle Cloud Infrastructure Database service.

    Gets details of the Exadata Infrastructure target system software versions that can be applied to the specified infrastructure resource for maintenance updates.
    Applies to Exadata Cloud@Customer and Exadata Cloud instances only.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_infrastructure_target_version = oci.Database.get_infrastructure_target_version(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str target_resource_id: The target resource ID.
    :param str target_resource_type: The type of the target resource.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['targetResourceId'] = target_resource_id
    __args__['targetResourceType'] = target_resource_type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getInfrastructureTargetVersion:getInfrastructureTargetVersion', __args__, opts=opts, typ=GetInfrastructureTargetVersionResult).value

    return AwaitableGetInfrastructureTargetVersionResult(
        compartment_id=__ret__.compartment_id,
        id=__ret__.id,
        target_db_version_history_entries=__ret__.target_db_version_history_entries,
        target_resource_id=__ret__.target_resource_id,
        target_resource_type=__ret__.target_resource_type,
        target_storage_version_history_entries=__ret__.target_storage_version_history_entries)


@_utilities.lift_output_func(get_infrastructure_target_version)
def get_infrastructure_target_version_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                             target_resource_id: Optional[pulumi.Input[Optional[str]]] = None,
                                             target_resource_type: Optional[pulumi.Input[Optional[str]]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInfrastructureTargetVersionResult]:
    """
    This data source provides details about a specific Infrastructure Target Version resource in Oracle Cloud Infrastructure Database service.

    Gets details of the Exadata Infrastructure target system software versions that can be applied to the specified infrastructure resource for maintenance updates.
    Applies to Exadata Cloud@Customer and Exadata Cloud instances only.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_infrastructure_target_version = oci.Database.get_infrastructure_target_version(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_resource_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        target_resource_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The compartment [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str target_resource_id: The target resource ID.
    :param str target_resource_type: The type of the target resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AnalyticsInstancePrivateAccessChannelArgs', 'AnalyticsInstancePrivateAccessChannel']

@pulumi.input_type
class AnalyticsInstancePrivateAccessChannelArgs:
    def __init__(__self__, *,
                 analytics_instance_id: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 private_source_dns_zones: pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]],
                 subnet_id: pulumi.Input[str],
                 vcn_id: pulumi.Input[str],
                 network_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 private_source_scan_hosts: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]] = None):
        """
        The set of arguments for constructing a AnalyticsInstancePrivateAccessChannel resource.
        :param pulumi.Input[str] analytics_instance_id: The OCID of the AnalyticsInstance.
        :param pulumi.Input[str] display_name: (Updatable) Display Name of the Private Access Channel.
        :param pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]] private_source_dns_zones: (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        :param pulumi.Input[str] subnet_id: (Updatable) OCID of the customer subnet connected to private access channel.
        :param pulumi.Input[str] vcn_id: (Updatable) OCID of the customer VCN peered with private access channel. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_security_group_ids: (Updatable) Network Security Group OCIDs for an Analytics instance.
        :param pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]] private_source_scan_hosts: (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        """
        pulumi.set(__self__, "analytics_instance_id", analytics_instance_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "private_source_dns_zones", private_source_dns_zones)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vcn_id", vcn_id)
        if network_security_group_ids is not None:
            pulumi.set(__self__, "network_security_group_ids", network_security_group_ids)
        if private_source_scan_hosts is not None:
            pulumi.set(__self__, "private_source_scan_hosts", private_source_scan_hosts)

    @property
    @pulumi.getter(name="analyticsInstanceId")
    def analytics_instance_id(self) -> pulumi.Input[str]:
        """
        The OCID of the AnalyticsInstance.
        """
        return pulumi.get(self, "analytics_instance_id")

    @analytics_instance_id.setter
    def analytics_instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "analytics_instance_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        (Updatable) Display Name of the Private Access Channel.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="privateSourceDnsZones")
    def private_source_dns_zones(self) -> pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]:
        """
        (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        """
        return pulumi.get(self, "private_source_dns_zones")

    @private_source_dns_zones.setter
    def private_source_dns_zones(self, value: pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]):
        pulumi.set(self, "private_source_dns_zones", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[str]:
        """
        (Updatable) OCID of the customer subnet connected to private access channel.
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> pulumi.Input[str]:
        """
        (Updatable) OCID of the customer VCN peered with private access channel. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "vcn_id")

    @vcn_id.setter
    def vcn_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "vcn_id", value)

    @property
    @pulumi.getter(name="networkSecurityGroupIds")
    def network_security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) Network Security Group OCIDs for an Analytics instance.
        """
        return pulumi.get(self, "network_security_group_ids")

    @network_security_group_ids.setter
    def network_security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "network_security_group_ids", value)

    @property
    @pulumi.getter(name="privateSourceScanHosts")
    def private_source_scan_hosts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]:
        """
        (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        """
        return pulumi.get(self, "private_source_scan_hosts")

    @private_source_scan_hosts.setter
    def private_source_scan_hosts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]):
        pulumi.set(self, "private_source_scan_hosts", value)


@pulumi.input_type
class _AnalyticsInstancePrivateAccessChannelState:
    def __init__(__self__, *,
                 analytics_instance_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 egress_source_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 ip_address: Optional[pulumi.Input[str]] = None,
                 key: Optional[pulumi.Input[str]] = None,
                 network_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 private_source_dns_zones: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]] = None,
                 private_source_scan_hosts: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 vcn_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AnalyticsInstancePrivateAccessChannel resources.
        :param pulumi.Input[str] analytics_instance_id: The OCID of the AnalyticsInstance.
        :param pulumi.Input[str] display_name: (Updatable) Display Name of the Private Access Channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] egress_source_ip_addresses: The list of IP addresses from the customer subnet connected to private access channel, used as a source Ip by Private Access Channel for network traffic from the AnalyticsInstance to Private Sources.
        :param pulumi.Input[str] ip_address: IP Address of the Private Access channel.
        :param pulumi.Input[str] key: Private Access Channel unique identifier key.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_security_group_ids: (Updatable) Network Security Group OCIDs for an Analytics instance.
        :param pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]] private_source_dns_zones: (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        :param pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]] private_source_scan_hosts: (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        :param pulumi.Input[str] subnet_id: (Updatable) OCID of the customer subnet connected to private access channel.
        :param pulumi.Input[str] vcn_id: (Updatable) OCID of the customer VCN peered with private access channel. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        if analytics_instance_id is not None:
            pulumi.set(__self__, "analytics_instance_id", analytics_instance_id)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if egress_source_ip_addresses is not None:
            pulumi.set(__self__, "egress_source_ip_addresses", egress_source_ip_addresses)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if network_security_group_ids is not None:
            pulumi.set(__self__, "network_security_group_ids", network_security_group_ids)
        if private_source_dns_zones is not None:
            pulumi.set(__self__, "private_source_dns_zones", private_source_dns_zones)
        if private_source_scan_hosts is not None:
            pulumi.set(__self__, "private_source_scan_hosts", private_source_scan_hosts)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if vcn_id is not None:
            pulumi.set(__self__, "vcn_id", vcn_id)

    @property
    @pulumi.getter(name="analyticsInstanceId")
    def analytics_instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the AnalyticsInstance.
        """
        return pulumi.get(self, "analytics_instance_id")

    @analytics_instance_id.setter
    def analytics_instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "analytics_instance_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Display Name of the Private Access Channel.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="egressSourceIpAddresses")
    def egress_source_ip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of IP addresses from the customer subnet connected to private access channel, used as a source Ip by Private Access Channel for network traffic from the AnalyticsInstance to Private Sources.
        """
        return pulumi.get(self, "egress_source_ip_addresses")

    @egress_source_ip_addresses.setter
    def egress_source_ip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "egress_source_ip_addresses", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[str]]:
        """
        IP Address of the Private Access channel.
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[str]]:
        """
        Private Access Channel unique identifier key.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter(name="networkSecurityGroupIds")
    def network_security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) Network Security Group OCIDs for an Analytics instance.
        """
        return pulumi.get(self, "network_security_group_ids")

    @network_security_group_ids.setter
    def network_security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "network_security_group_ids", value)

    @property
    @pulumi.getter(name="privateSourceDnsZones")
    def private_source_dns_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]]:
        """
        (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        """
        return pulumi.get(self, "private_source_dns_zones")

    @private_source_dns_zones.setter
    def private_source_dns_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]]):
        pulumi.set(self, "private_source_dns_zones", value)

    @property
    @pulumi.getter(name="privateSourceScanHosts")
    def private_source_scan_hosts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]:
        """
        (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        """
        return pulumi.get(self, "private_source_scan_hosts")

    @private_source_scan_hosts.setter
    def private_source_scan_hosts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]):
        pulumi.set(self, "private_source_scan_hosts", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) OCID of the customer subnet connected to private access channel.
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) OCID of the customer VCN peered with private access channel. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "vcn_id")

    @vcn_id.setter
    def vcn_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vcn_id", value)


class AnalyticsInstancePrivateAccessChannel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 analytics_instance_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 network_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 private_source_dns_zones: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]]] = None,
                 private_source_scan_hosts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 vcn_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Analytics Instance Private Access Channel resource in Oracle Cloud Infrastructure Analytics service.

        Create a Private access Channel for the Analytics instance. The operation is long-running
        and creates a new WorkRequest.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_analytics_instance_private_access_channel = oci.analytics.AnalyticsInstancePrivateAccessChannel("testAnalyticsInstancePrivateAccessChannel",
            analytics_instance_id=oci_analytics_analytics_instance["test_analytics_instance"]["id"],
            display_name=var["analytics_instance_private_access_channel_display_name"],
            private_source_dns_zones=[oci.analytics.AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs(
                dns_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            subnet_id=oci_core_subnet["test_subnet"]["id"],
            vcn_id=oci_core_vcn["test_vcn"]["id"],
            network_security_group_ids=var["analytics_instance_private_access_channel_network_security_group_ids"],
            private_source_scan_hosts=[oci.analytics.AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs(
                scan_hostname=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                scan_port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        AnalyticsInstancePrivateAccessChannels can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Analytics/analyticsInstancePrivateAccessChannel:AnalyticsInstancePrivateAccessChannel test_analytics_instance_private_access_channel "analyticsInstances/{analyticsInstanceId}/privateAccessChannels/{privateAccessChannelKey}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] analytics_instance_id: The OCID of the AnalyticsInstance.
        :param pulumi.Input[str] display_name: (Updatable) Display Name of the Private Access Channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_security_group_ids: (Updatable) Network Security Group OCIDs for an Analytics instance.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]] private_source_dns_zones: (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]] private_source_scan_hosts: (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        :param pulumi.Input[str] subnet_id: (Updatable) OCID of the customer subnet connected to private access channel.
        :param pulumi.Input[str] vcn_id: (Updatable) OCID of the customer VCN peered with private access channel. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AnalyticsInstancePrivateAccessChannelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Analytics Instance Private Access Channel resource in Oracle Cloud Infrastructure Analytics service.

        Create a Private access Channel for the Analytics instance. The operation is long-running
        and creates a new WorkRequest.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_analytics_instance_private_access_channel = oci.analytics.AnalyticsInstancePrivateAccessChannel("testAnalyticsInstancePrivateAccessChannel",
            analytics_instance_id=oci_analytics_analytics_instance["test_analytics_instance"]["id"],
            display_name=var["analytics_instance_private_access_channel_display_name"],
            private_source_dns_zones=[oci.analytics.AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs(
                dns_zone=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )],
            subnet_id=oci_core_subnet["test_subnet"]["id"],
            vcn_id=oci_core_vcn["test_vcn"]["id"],
            network_security_group_ids=var["analytics_instance_private_access_channel_network_security_group_ids"],
            private_source_scan_hosts=[oci.analytics.AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs(
                scan_hostname=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                scan_port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                description=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            )])
        ```

        ## Import

        AnalyticsInstancePrivateAccessChannels can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Analytics/analyticsInstancePrivateAccessChannel:AnalyticsInstancePrivateAccessChannel test_analytics_instance_private_access_channel "analyticsInstances/{analyticsInstanceId}/privateAccessChannels/{privateAccessChannelKey}"
        ```

        :param str resource_name: The name of the resource.
        :param AnalyticsInstancePrivateAccessChannelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AnalyticsInstancePrivateAccessChannelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 analytics_instance_id: Optional[pulumi.Input[str]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 network_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 private_source_dns_zones: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]]] = None,
                 private_source_scan_hosts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 vcn_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AnalyticsInstancePrivateAccessChannelArgs.__new__(AnalyticsInstancePrivateAccessChannelArgs)

            if analytics_instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'analytics_instance_id'")
            __props__.__dict__["analytics_instance_id"] = analytics_instance_id
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["network_security_group_ids"] = network_security_group_ids
            if private_source_dns_zones is None and not opts.urn:
                raise TypeError("Missing required property 'private_source_dns_zones'")
            __props__.__dict__["private_source_dns_zones"] = private_source_dns_zones
            __props__.__dict__["private_source_scan_hosts"] = private_source_scan_hosts
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            if vcn_id is None and not opts.urn:
                raise TypeError("Missing required property 'vcn_id'")
            __props__.__dict__["vcn_id"] = vcn_id
            __props__.__dict__["egress_source_ip_addresses"] = None
            __props__.__dict__["ip_address"] = None
            __props__.__dict__["key"] = None
        super(AnalyticsInstancePrivateAccessChannel, __self__).__init__(
            'oci:Analytics/analyticsInstancePrivateAccessChannel:AnalyticsInstancePrivateAccessChannel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            analytics_instance_id: Optional[pulumi.Input[str]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            egress_source_ip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            ip_address: Optional[pulumi.Input[str]] = None,
            key: Optional[pulumi.Input[str]] = None,
            network_security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            private_source_dns_zones: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]]] = None,
            private_source_scan_hosts: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]]] = None,
            subnet_id: Optional[pulumi.Input[str]] = None,
            vcn_id: Optional[pulumi.Input[str]] = None) -> 'AnalyticsInstancePrivateAccessChannel':
        """
        Get an existing AnalyticsInstancePrivateAccessChannel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] analytics_instance_id: The OCID of the AnalyticsInstance.
        :param pulumi.Input[str] display_name: (Updatable) Display Name of the Private Access Channel.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] egress_source_ip_addresses: The list of IP addresses from the customer subnet connected to private access channel, used as a source Ip by Private Access Channel for network traffic from the AnalyticsInstance to Private Sources.
        :param pulumi.Input[str] ip_address: IP Address of the Private Access channel.
        :param pulumi.Input[str] key: Private Access Channel unique identifier key.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] network_security_group_ids: (Updatable) Network Security Group OCIDs for an Analytics instance.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZoneArgs']]]] private_source_dns_zones: (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['AnalyticsInstancePrivateAccessChannelPrivateSourceScanHostArgs']]]] private_source_scan_hosts: (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        :param pulumi.Input[str] subnet_id: (Updatable) OCID of the customer subnet connected to private access channel.
        :param pulumi.Input[str] vcn_id: (Updatable) OCID of the customer VCN peered with private access channel. 
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AnalyticsInstancePrivateAccessChannelState.__new__(_AnalyticsInstancePrivateAccessChannelState)

        __props__.__dict__["analytics_instance_id"] = analytics_instance_id
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["egress_source_ip_addresses"] = egress_source_ip_addresses
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["key"] = key
        __props__.__dict__["network_security_group_ids"] = network_security_group_ids
        __props__.__dict__["private_source_dns_zones"] = private_source_dns_zones
        __props__.__dict__["private_source_scan_hosts"] = private_source_scan_hosts
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["vcn_id"] = vcn_id
        return AnalyticsInstancePrivateAccessChannel(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="analyticsInstanceId")
    def analytics_instance_id(self) -> pulumi.Output[str]:
        """
        The OCID of the AnalyticsInstance.
        """
        return pulumi.get(self, "analytics_instance_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) Display Name of the Private Access Channel.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="egressSourceIpAddresses")
    def egress_source_ip_addresses(self) -> pulumi.Output[Sequence[str]]:
        """
        The list of IP addresses from the customer subnet connected to private access channel, used as a source Ip by Private Access Channel for network traffic from the AnalyticsInstance to Private Sources.
        """
        return pulumi.get(self, "egress_source_ip_addresses")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[str]:
        """
        IP Address of the Private Access channel.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter
    def key(self) -> pulumi.Output[str]:
        """
        Private Access Channel unique identifier key.
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="networkSecurityGroupIds")
    def network_security_group_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        (Updatable) Network Security Group OCIDs for an Analytics instance.
        """
        return pulumi.get(self, "network_security_group_ids")

    @property
    @pulumi.getter(name="privateSourceDnsZones")
    def private_source_dns_zones(self) -> pulumi.Output[Sequence['outputs.AnalyticsInstancePrivateAccessChannelPrivateSourceDnsZone']]:
        """
        (Updatable) List of Private Source DNS zones registered with Private Access Channel, where datasource hostnames from these dns zones / domains will be resolved in the peered VCN for access from Analytics Instance. Min of 1 is required and Max of 30 Private Source DNS zones can be registered.
        """
        return pulumi.get(self, "private_source_dns_zones")

    @property
    @pulumi.getter(name="privateSourceScanHosts")
    def private_source_scan_hosts(self) -> pulumi.Output[Sequence['outputs.AnalyticsInstancePrivateAccessChannelPrivateSourceScanHost']]:
        """
        (Updatable) List of Private Source DB SCAN hosts registered with Private Access Channel for access from Analytics Instance.
        """
        return pulumi.get(self, "private_source_scan_hosts")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[str]:
        """
        (Updatable) OCID of the customer subnet connected to private access channel.
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> pulumi.Output[str]:
        """
        (Updatable) OCID of the customer VCN peered with private access channel. 


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "vcn_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetTrailFilesResult',
    'AwaitableGetTrailFilesResult',
    'get_trail_files',
    'get_trail_files_output',
]

@pulumi.output_type
class GetTrailFilesResult:
    """
    A collection of values returned by getTrailFiles.
    """
    def __init__(__self__, deployment_id=None, display_name=None, filters=None, id=None, trail_file_collections=None, trail_file_id=None):
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if trail_file_collections and not isinstance(trail_file_collections, list):
            raise TypeError("Expected argument 'trail_file_collections' to be a list")
        pulumi.set(__self__, "trail_file_collections", trail_file_collections)
        if trail_file_id and not isinstance(trail_file_id, str):
            raise TypeError("Expected argument 'trail_file_id' to be a str")
        pulumi.set(__self__, "trail_file_id", trail_file_id)

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        An object's Display Name.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetTrailFilesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="trailFileCollections")
    def trail_file_collections(self) -> Sequence['outputs.GetTrailFilesTrailFileCollectionResult']:
        """
        The list of trail_file_collection.
        """
        return pulumi.get(self, "trail_file_collections")

    @property
    @pulumi.getter(name="trailFileId")
    def trail_file_id(self) -> str:
        """
        The TrailFile Id.
        """
        return pulumi.get(self, "trail_file_id")


class AwaitableGetTrailFilesResult(GetTrailFilesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrailFilesResult(
            deployment_id=self.deployment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            trail_file_collections=self.trail_file_collections,
            trail_file_id=self.trail_file_id)


def get_trail_files(deployment_id: Optional[str] = None,
                    display_name: Optional[str] = None,
                    filters: Optional[Sequence[pulumi.InputType['GetTrailFilesFilterArgs']]] = None,
                    trail_file_id: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrailFilesResult:
    """
    This data source provides the list of Trail Files in Oracle Cloud Infrastructure Golden Gate service.

    Lists the TrailFiles for a deployment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_trail_files = oci.GoldenGate.get_trail_files(deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        trail_file_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str deployment_id: A unique Deployment identifier.
    :param str display_name: A filter to return only the resources that match the entire 'displayName' given.
    :param str trail_file_id: A Trail File identifier
    """
    __args__ = dict()
    __args__['deploymentId'] = deployment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['trailFileId'] = trail_file_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:GoldenGate/getTrailFiles:getTrailFiles', __args__, opts=opts, typ=GetTrailFilesResult).value

    return AwaitableGetTrailFilesResult(
        deployment_id=__ret__.deployment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        trail_file_collections=__ret__.trail_file_collections,
        trail_file_id=__ret__.trail_file_id)


@_utilities.lift_output_func(get_trail_files)
def get_trail_files_output(deployment_id: Optional[pulumi.Input[str]] = None,
                           display_name: Optional[pulumi.Input[Optional[str]]] = None,
                           filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetTrailFilesFilterArgs']]]]] = None,
                           trail_file_id: Optional[pulumi.Input[str]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetTrailFilesResult]:
    """
    This data source provides the list of Trail Files in Oracle Cloud Infrastructure Golden Gate service.

    Lists the TrailFiles for a deployment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_trail_files = oci.GoldenGate.get_trail_files(deployment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        trail_file_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str deployment_id: A unique Deployment identifier.
    :param str display_name: A filter to return only the resources that match the entire 'displayName' given.
    :param str trail_file_id: A Trail File identifier
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetCompatibleFormatsForDataTypeResult',
    'AwaitableGetCompatibleFormatsForDataTypeResult',
    'get_compatible_formats_for_data_type',
]

@pulumi.output_type
class GetCompatibleFormatsForDataTypeResult:
    """
    A collection of values returned by getCompatibleFormatsForDataType.
    """
    def __init__(__self__, formats_for_data_types=None, id=None):
        if formats_for_data_types and not isinstance(formats_for_data_types, list):
            raise TypeError("Expected argument 'formats_for_data_types' to be a list")
        pulumi.set(__self__, "formats_for_data_types", formats_for_data_types)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="formatsForDataTypes")
    def formats_for_data_types(self) -> Sequence['outputs.GetCompatibleFormatsForDataTypeFormatsForDataTypeResult']:
        """
        An array of lists of basic masking formats compatible with the supported data types.
        """
        return pulumi.get(self, "formats_for_data_types")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetCompatibleFormatsForDataTypeResult(GetCompatibleFormatsForDataTypeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCompatibleFormatsForDataTypeResult(
            formats_for_data_types=self.formats_for_data_types,
            id=self.id)


def get_compatible_formats_for_data_type(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCompatibleFormatsForDataTypeResult:
    """
    This data source provides details about a specific Compatible Formats For Data Type resource in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of basic masking formats compatible with the supported data types.
    The data types are grouped into the following categories -
    Character - Includes CHAR, NCHAR, VARCHAR2, and NVARCHAR2
    Numeric - Includes NUMBER, FLOAT, RAW, BINARY_FLOAT, and BINARY_DOUBLE
    Date - Includes DATE and TIMESTAMP
    LOB - Includes BLOB, CLOB, and NCLOB
    All - Includes all the supported data types

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_compatible_formats_for_data_type = oci.DataSafe.get_compatible_formats_for_data_type()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getCompatibleFormatsForDataType:getCompatibleFormatsForDataType', __args__, opts=opts, typ=GetCompatibleFormatsForDataTypeResult).value

    return AwaitableGetCompatibleFormatsForDataTypeResult(
        formats_for_data_types=__ret__.formats_for_data_types,
        id=__ret__.id)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstanceConfigurationResult',
    'AwaitableGetInstanceConfigurationResult',
    'get_instance_configuration',
    'get_instance_configuration_output',
]

@pulumi.output_type
class GetInstanceConfigurationResult:
    """
    A collection of values returned by getInstanceConfiguration.
    """
    def __init__(__self__, compartment_id=None, deferred_fields=None, defined_tags=None, display_name=None, freeform_tags=None, id=None, instance_configuration_id=None, instance_details=None, instance_id=None, source=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if deferred_fields and not isinstance(deferred_fields, list):
            raise TypeError("Expected argument 'deferred_fields' to be a list")
        pulumi.set(__self__, "deferred_fields", deferred_fields)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_configuration_id and not isinstance(instance_configuration_id, str):
            raise TypeError("Expected argument 'instance_configuration_id' to be a str")
        pulumi.set(__self__, "instance_configuration_id", instance_configuration_id)
        if instance_details and not isinstance(instance_details, list):
            raise TypeError("Expected argument 'instance_details' to be a list")
        pulumi.set(__self__, "instance_details", instance_details)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if source and not isinstance(source, str):
            raise TypeError("Expected argument 'source' to be a str")
        pulumi.set(__self__, "source", source)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The OCID of the compartment containing the instance. Instances created from instance configurations are placed in the same compartment as the instance that was used to create the instance configuration.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="deferredFields")
    def deferred_fields(self) -> Sequence[str]:
        """
        Parameters that were not specified when the instance configuration was created, but that are required to launch an instance from the instance configuration. See the [LaunchInstanceConfiguration](https://docs.cloud.oracle.com/iaas/api/#/en/iaas/latest/Instance/LaunchInstanceConfiguration) operation.
        """
        return pulumi.get(self, "deferred_fields")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the volume backup.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceConfigurationId")
    def instance_configuration_id(self) -> str:
        return pulumi.get(self, "instance_configuration_id")

    @property
    @pulumi.getter(name="instanceDetails")
    def instance_details(self) -> Sequence['outputs.GetInstanceConfigurationInstanceDetailResult']:
        return pulumi.get(self, "instance_details")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def source(self) -> str:
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the instance configuration was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).  Example: `2016-08-25T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")


class AwaitableGetInstanceConfigurationResult(GetInstanceConfigurationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceConfigurationResult(
            compartment_id=self.compartment_id,
            deferred_fields=self.deferred_fields,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            instance_configuration_id=self.instance_configuration_id,
            instance_details=self.instance_details,
            instance_id=self.instance_id,
            source=self.source,
            time_created=self.time_created)


def get_instance_configuration(instance_configuration_id: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceConfigurationResult:
    """
    This data source provides details about a specific Instance Configuration resource in Oracle Cloud Infrastructure Core service.

    Gets the specified instance configuration

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_instance_configuration = oci.Core.get_instance_configuration(instance_configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str instance_configuration_id: The OCID of the instance configuration.
    """
    __args__ = dict()
    __args__['instanceConfigurationId'] = instance_configuration_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getInstanceConfiguration:getInstanceConfiguration', __args__, opts=opts, typ=GetInstanceConfigurationResult).value

    return AwaitableGetInstanceConfigurationResult(
        compartment_id=__ret__.compartment_id,
        deferred_fields=__ret__.deferred_fields,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        instance_configuration_id=__ret__.instance_configuration_id,
        instance_details=__ret__.instance_details,
        instance_id=__ret__.instance_id,
        source=__ret__.source,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_instance_configuration)
def get_instance_configuration_output(instance_configuration_id: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceConfigurationResult]:
    """
    This data source provides details about a specific Instance Configuration resource in Oracle Cloud Infrastructure Core service.

    Gets the specified instance configuration

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_instance_configuration = oci.Core.get_instance_configuration(instance_configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str instance_configuration_id: The OCID of the instance configuration.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetOceInstancesResult',
    'AwaitableGetOceInstancesResult',
    'get_oce_instances',
    'get_oce_instances_output',
]

@pulumi.output_type
class GetOceInstancesResult:
    """
    A collection of values returned by getOceInstances.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, oce_instances=None, state=None, tenancy_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if oce_instances and not isinstance(oce_instances, list):
            raise TypeError("Expected argument 'oce_instances' to be a list")
        pulumi.set(__self__, "oce_instances", oce_instances)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if tenancy_id and not isinstance(tenancy_id, str):
            raise TypeError("Expected argument 'tenancy_id' to be a str")
        pulumi.set(__self__, "tenancy_id", tenancy_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        Compartment Identifier
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetOceInstancesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="oceInstances")
    def oce_instances(self) -> Sequence['outputs.GetOceInstancesOceInstanceResult']:
        """
        The list of oce_instances.
        """
        return pulumi.get(self, "oce_instances")

    @property
    @pulumi.getter
    def state(self) -> Optional[str]:
        """
        The current state of the instance lifecycle.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="tenancyId")
    def tenancy_id(self) -> Optional[str]:
        """
        Tenancy Identifier
        """
        return pulumi.get(self, "tenancy_id")


class AwaitableGetOceInstancesResult(GetOceInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOceInstancesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            oce_instances=self.oce_instances,
            state=self.state,
            tenancy_id=self.tenancy_id)


def get_oce_instances(compartment_id: Optional[str] = None,
                      display_name: Optional[str] = None,
                      filters: Optional[Sequence[pulumi.InputType['GetOceInstancesFilterArgs']]] = None,
                      state: Optional[str] = None,
                      tenancy_id: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOceInstancesResult:
    """
    This data source provides the list of Oce Instances in Oracle Cloud Infrastructure Content and Experience service.

    Returns a list of OceInstances.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_oce_instances = oci.Oce.get_oce_instances(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        tenancy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A user-friendly name. Does not have to be unique, and it's changeable.  Example: `My new resource`
    :param str state: Filter results on lifecycleState.
    :param str tenancy_id: The ID of the tenancy in which to list resources.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['state'] = state
    __args__['tenancyId'] = tenancy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Oce/getOceInstances:getOceInstances', __args__, opts=opts, typ=GetOceInstancesResult).value

    return AwaitableGetOceInstancesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        oce_instances=__ret__.oce_instances,
        state=__ret__.state,
        tenancy_id=__ret__.tenancy_id)


@_utilities.lift_output_func(get_oce_instances)
def get_oce_instances_output(compartment_id: Optional[pulumi.Input[str]] = None,
                             display_name: Optional[pulumi.Input[Optional[str]]] = None,
                             filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetOceInstancesFilterArgs']]]]] = None,
                             state: Optional[pulumi.Input[Optional[str]]] = None,
                             tenancy_id: Optional[pulumi.Input[Optional[str]]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOceInstancesResult]:
    """
    This data source provides the list of Oce Instances in Oracle Cloud Infrastructure Content and Experience service.

    Returns a list of OceInstances.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_oce_instances = oci.Oce.get_oce_instances(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        state=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        tenancy_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The ID of the compartment in which to list resources.
    :param str display_name: A user-friendly name. Does not have to be unique, and it's changeable.  Example: `My new resource`
    :param str state: Filter results on lifecycleState.
    :param str tenancy_id: The ID of the tenancy in which to list resources.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetQueryResult',
    'AwaitableGetQueryResult',
    'get_query',
    'get_query_output',
]

@pulumi.output_type
class GetQueryResult:
    """
    A collection of values returned by getQuery.
    """
    def __init__(__self__, compartment_id=None, id=None, query_definitions=None, query_id=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if query_definitions and not isinstance(query_definitions, list):
            raise TypeError("Expected argument 'query_definitions' to be a list")
        pulumi.set(__self__, "query_definitions", query_definitions)
        if query_id and not isinstance(query_id, str):
            raise TypeError("Expected argument 'query_id' to be a str")
        pulumi.set(__self__, "query_id", query_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The compartment OCID.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The query OCID.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="queryDefinitions")
    def query_definitions(self) -> Sequence['outputs.GetQueryQueryDefinitionResult']:
        """
        The common fields for queries.
        """
        return pulumi.get(self, "query_definitions")

    @property
    @pulumi.getter(name="queryId")
    def query_id(self) -> str:
        return pulumi.get(self, "query_id")


class AwaitableGetQueryResult(GetQueryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetQueryResult(
            compartment_id=self.compartment_id,
            id=self.id,
            query_definitions=self.query_definitions,
            query_id=self.query_id)


def get_query(query_id: Optional[str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetQueryResult:
    """
    This data source provides details about a specific Query resource in Oracle Cloud Infrastructure Metering Computation service.

    Returns the saved query.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_query = oci.MeteringComputation.get_query(query_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str query_id: The query unique OCID.
    """
    __args__ = dict()
    __args__['queryId'] = query_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:MeteringComputation/getQuery:getQuery', __args__, opts=opts, typ=GetQueryResult).value

    return AwaitableGetQueryResult(
        compartment_id=__ret__.compartment_id,
        id=__ret__.id,
        query_definitions=__ret__.query_definitions,
        query_id=__ret__.query_id)


@_utilities.lift_output_func(get_query)
def get_query_output(query_id: Optional[pulumi.Input[str]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetQueryResult]:
    """
    This data source provides details about a specific Query resource in Oracle Cloud Infrastructure Metering Computation service.

    Returns the saved query.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_query = oci.MeteringComputation.get_query(query_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str query_id: The query unique OCID.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetNamespaceMetadataResult',
    'AwaitableGetNamespaceMetadataResult',
    'get_namespace_metadata',
    'get_namespace_metadata_output',
]

@pulumi.output_type
class GetNamespaceMetadataResult:
    """
    A collection of values returned by getNamespaceMetadata.
    """
    def __init__(__self__, default_s3compartment_id=None, default_swift_compartment_id=None, id=None, namespace=None):
        if default_s3compartment_id and not isinstance(default_s3compartment_id, str):
            raise TypeError("Expected argument 'default_s3compartment_id' to be a str")
        pulumi.set(__self__, "default_s3compartment_id", default_s3compartment_id)
        if default_swift_compartment_id and not isinstance(default_swift_compartment_id, str):
            raise TypeError("Expected argument 'default_swift_compartment_id' to be a str")
        pulumi.set(__self__, "default_swift_compartment_id", default_swift_compartment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if namespace and not isinstance(namespace, str):
            raise TypeError("Expected argument 'namespace' to be a str")
        pulumi.set(__self__, "namespace", namespace)

    @property
    @pulumi.getter(name="defaultS3compartmentId")
    def default_s3compartment_id(self) -> str:
        return pulumi.get(self, "default_s3compartment_id")

    @property
    @pulumi.getter(name="defaultSwiftCompartmentId")
    def default_swift_compartment_id(self) -> str:
        return pulumi.get(self, "default_swift_compartment_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def namespace(self) -> str:
        return pulumi.get(self, "namespace")


class AwaitableGetNamespaceMetadataResult(GetNamespaceMetadataResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNamespaceMetadataResult(
            default_s3compartment_id=self.default_s3compartment_id,
            default_swift_compartment_id=self.default_swift_compartment_id,
            id=self.id,
            namespace=self.namespace)


def get_namespace_metadata(namespace: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNamespaceMetadataResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['namespace'] = namespace
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ObjectStorage/getNamespaceMetadata:getNamespaceMetadata', __args__, opts=opts, typ=GetNamespaceMetadataResult).value

    return AwaitableGetNamespaceMetadataResult(
        default_s3compartment_id=__ret__.default_s3compartment_id,
        default_swift_compartment_id=__ret__.default_swift_compartment_id,
        id=__ret__.id,
        namespace=__ret__.namespace)


@_utilities.lift_output_func(get_namespace_metadata)
def get_namespace_metadata_output(namespace: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNamespaceMetadataResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...
